@@ -1,10 +1,10 @@
 # @package      hubzero-submit-distributor
 # @file         VenueMechanismCore.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -35,9 +35,10 @@ import datetime
 import re
 import shutil
 import copy
+import logging
 from errno import EPIPE
 
-from hubzero.submit.LogMessage   import logID as log
+from hubzero.submit.LogMessage   import getLogIDMessage as getLogMessage
 from hubzero.submit.JobStatistic import JobStatistic
 
 class VenueMechanismCore:
@@ -50,6 +51,7 @@ class VenueMechanismCore:
                 nCpus,
                 nNodes,
                 ppn):
+      self.logger              = logging.getLogger(__name__)
       self.timeHistoryLogs     = copy.copy(timeHistoryLogs)
       self.siteInfo            = copy.copy(siteInfo)
       self.managerInfo         = copy.copy(managerInfo)
@@ -90,24 +92,24 @@ class VenueMechanismCore:
       self.stageInTarFile    = ""
 
 
-   @staticmethod
-   def __writeToStdout(message):
+   def _writeToStdout(self,
+                      message):
       try:
          sys.stdout.write(message)
          sys.stdout.flush()
       except IOError,err:
          if not err[0] in [EPIPE]:
-            log("Can't write to stdout: %s" % (message))
+            self.logger.log(logging.ERROR,getLogMessage("Can't write to stdout: %s" % (message)))
 
 
-   @staticmethod
-   def __writeToStderr(message):
+   def _writeToStderr(self,
+                      message):
       try:
          sys.stderr.write(message)
          sys.stderr.flush()
       except IOError,err:
          if not err[0] in [EPIPE]:
-            log("Can't write to stderr: %s" % (message))
+            self.logger.log(logging.ERROR,getLogMessage("Can't write to stderr: %s" % (message)))
 
 
    def recordGridResourceUse(self):
@@ -145,7 +147,8 @@ class VenueMechanismCore:
 
             os.remove(os.path.join(self.instanceDirectory,matchingFile))
       else:
-         log(self.timeHistoryLogs['jobGridResource'] + " not present in " + self.instanceDirectory)
+         message = self.timeHistoryLogs['jobGridResource'] + " not present in " + self.instanceDirectory
+         self.logger.log(logging.ERROR,getLogMessage(message))
 
 
    def logGridHistories(self):
@@ -232,7 +235,8 @@ class VenueMechanismCore:
          if fpGridJobIdLog:
             fpGridJobIdLog.close()
       else:
-         log(self.timeHistoryLogs['jobGridJobId'] + " not present in " + self.instanceDirectory)
+         message = self.timeHistoryLogs['jobGridJobId'] + " not present in " + self.instanceDirectory
+         self.logger.log(logging.ERROR,getLogMessage(message))
 
 
    def executeCommand(self,
@@ -271,7 +275,7 @@ class VenueMechanismCore:
                outEOF = True
             outData.append(outChunk)
             if streamOutput:
-               self.__writeToStdout(outChunk)
+               self._writeToStdout(outChunk)
 
          if childerrFd in ready[0]:
             errChunk = os.read(childerrFd,self.bufferSize)
@@ -279,7 +283,7 @@ class VenueMechanismCore:
                errEOF = True
             errData.append(errChunk)
             if streamOutput:
-               self.__writeToStderr(errChunk)
+               self._writeToStderr(errChunk)
 
          if outEOF and errEOF:
             break
@@ -288,13 +292,13 @@ class VenueMechanismCore:
       self.childPid = 0
       if err != 0:
          if   os.WIFSIGNALED(err):
-            log("%s failed w/ signal %d" % (command,os.WTERMSIG(err)))
+            self.logger.log(logging.ERROR,getLogMessage("%s failed w/ signal %d" % (command,os.WTERMSIG(err))))
          else:
             if os.WIFEXITED(err):
                err = os.WEXITSTATUS(err)
-            log("%s failed w/ exit code %d" % (command,err))
+            self.logger.log(logging.ERROR,getLogMessage("%s failed w/ exit code %d" % (command,err)))
          if not streamOutput:
-            log("%s" % ("".join(errData)))
+            self.logger.log(logging.ERROR,getLogMessage("%s" % ("".join(errData))))
 
       return(err,"".join(outData),"".join(errData))
 
@@ -413,10 +417,10 @@ class VenueMechanismCore:
             maximumJobIndex = max(self.jobStatistics.keys())
             if len(foundIndexes) != maximumJobIndex:
                for missingIndex in set(range(1,maximumJobIndex+1)).difference(set(foundIndexes)):
-                  log(timeFileBasename + '_' + str(missingIndex) + " is missing")
+                  self.logger.log(logging.ERROR,getLogMessage(timeFileBasename + '_' + str(missingIndex) + " is missing"))
          del foundIndexes
       else:
-         log(timeFileBasename + " not present in " + self.instanceDirectory)
+         self.logger.log(logging.ERROR,getLogMessage(timeFileBasename + " not present in " + self.instanceDirectory))
 
 
    def recordJobStatisticTimer(self,
@@ -496,7 +500,7 @@ class VenueMechanismCore:
 
                if self.jobStatistics[jobIndex]['exitCode'] == 2:
                   if exitSignal > 0:
-                     self.jobStatistics[jobIndex]['exitCode'] = exitStatus << 8 | exitSignal
+                     self.jobStatistics[jobIndex]['exitCode'] = exitStatus << 7 | exitSignal
                   else:
                      self.jobStatistics[jobIndex]['exitCode'] = exitStatus
                self.jobStatistics[jobIndex]['realTime']       = realTime
@@ -517,11 +521,11 @@ class VenueMechanismCore:
             maximumJobIndex = max(self.jobStatistics.keys())
             if len(foundIndexes) != maximumJobIndex:
                for missingIndex in set(range(1,maximumJobIndex+1)).difference(set(foundIndexes)):
-                  log(timeFileBasename + '_' + str(missingIndex) + " is missing")
+                  self.logger.log(logging.ERROR,getLogMessage(timeFileBasename + '_' + str(missingIndex) + " is missing"))
          del foundIndexes
       else:
          if self.jobSubmitted:
-            log(timeFileBasename + " not present in " + self.instanceDirectory)
+            self.logger.log(logging.ERROR,getLogMessage(timeFileBasename + " not present in " + self.instanceDirectory))
 
 
    def recordJobStatistics(self):
@@ -589,7 +593,7 @@ class VenueMechanismCore:
       if os.path.isdir(src):
          if os.path.exists(dst):
             if not os.path.isdir(dst):
-               log("moveTree: %s must be a directory" % (dst))
+               self.logger.log(logging.ERROR,getLogMessage("moveTree: %s must be a directory" % (dst)))
                return
          else:
             os.mkdir(dst)
@@ -606,9 +610,9 @@ class VenueMechanismCore:
                else:
                   os.rename(srcPath,dstPath)
             except (IOError,os.error),why:
-               log("moveTree: Can't move %s to %s: %s" % (srcPath,dstPath,str(why)))
+               self.logger.log(logging.ERROR,getLogMessage("moveTree: Can't move %s to %s: %s" % (srcPath,dstPath,str(why))))
       else:
-         log("moveTree: %s must be a directory" % (src))
+         self.logger.log(logging.ERROR,getLogMessage("moveTree: %s must be a directory" % (src)))
 
 
    def recoverFiles(self,
@@ -618,7 +622,7 @@ class VenueMechanismCore:
             jobDirectory = os.getcwd()
             dirFiles = os.listdir(self.instanceDirectory)
             if ingoreInstanceFiles:
-               reIgnoreFiles = re.compile(".*%s_%s.*" % (self.localJobId,self.instanceId))
+               reIgnoreFiles = re.compile(".*%s_%s.*" % (self.runName,self.instanceId))
                ignoreFiles = filter(reIgnoreFiles.search,dirFiles)
                for ignoreFile in ignoreFiles:
                   dirFiles.remove(ignoreFile)
@@ -632,15 +636,15 @@ class VenueMechanismCore:
                   else:
                      os.rename(srcFile,dstFile)
                except:
-                  log("%s recovery failed" % (srcFile))
+                  self.logger.log(logging.ERROR,getLogMessage("%s recovery failed" % (srcFile)))
 
 
    def recoverStdFiles(self):
       if self.instanceDirectory != os.getcwd():
          for fileType in 'stderr','stdout','FAILURE':
-            fileToRecover = os.path.join(self.instanceDirectory,"%s_%s.%s" % (self.localJobId,self.instanceId,fileType))
+            fileToRecover = os.path.join(self.instanceDirectory,"%s_%s.%s" % (self.runName,self.instanceId,fileType))
             if os.path.exists(fileToRecover):
-               fileToAppend = "%s.%s" % (self.localJobId,fileType)
+               fileToAppend = "%s.%s" % (self.runName,fileType)
                fpAppend = open(fileToAppend,'a')
                if fpAppend:
                   fpRecover = open(fileToRecover,'r')
